==> Gambio v4.1.1.2.zip: Vollversion GX v4.1.1.2/Shopsystem/Dateien/lang/german/original_sections/admin/voucher/gift_vouchers_config.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   gift_vouchers_config.lang.inc.php 2020-01-02
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'config_page_title'                => 'Gutscheinsystem',
    'heading_automatic_release_emails' => 'Automatischer Versand der Gutscheincodes',
    'save_configuration'               => 'Speichern',
    'orders_statuses_for_release'      => 'Bestellstatus für automatischen Versand von Gutscheincodes',
    'configuration_saved'              => 'Konfiguration gespeichert',
    'technical_parameters'             => 'Technische Parameter',
    'code_length'                      => 'Länge der Gutschein-Codes',
    'code_length_tt'                   => 'Geben Sie hier die Länge des Gutschein-Code ein. (max. 16 Zeichen)',
    'welcome_voucher_coupon'           => 'Willkommensgeschenk/-rabatt',
    'welcome_voucher_value'            => 'Willkommensgeschenk Gutscheinwert',
    'welcome_voucher_value_tt'         => 'Willkommensgeschenk Gutscheinwert: Wenn Sie keinen Gutschein in Ihrer Willkommens-E-Mail versenden wollen, verwenden Sie den Wert 0.00, ansonsten geben Sie den Wert des Gutscheins an. Z. B. 10.00 oder 50.00, aber keine Währungszeichen',
    'welcome_coupon_code'              => 'Willkommensrabatt-Couponcode',
    'welcome_coupon_code_tt'           => 'Willkommensrabatt-Couponcode: Wenn Sie keinen Coupon in Ihrer Willkommens-E-Mail versenden wollen, lassen Sie dieses Feld leer, ansonsten tragen Sie den Couponcode ein, den Sie verwenden wollen.',
];

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/lang/german/original_sections/admin/voucher/gift_vouchers_config.lang.inc.php <==
<?php
/* --------------------------------------------------------------
   gift_vouchers_config.lang.inc.php 2020-01-02
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2019 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

$t_language_text_section_content_array = [
    'config_page_title'                => 'Gutscheinsystem',
    'heading_automatic_release_emails' => 'Automatischer Versand der Gutscheincodes',
    'save_configuration'               => 'Speichern',
    'orders_statuses_for_release'      => 'Bestellstatus für automatischen Versand von Gutscheincodes',
    'configuration_saved'              => 'Konfiguration gespeichert',
    'technical_parameters'             => 'Technische Parameter',
    'code_length'                      => 'Länge der Gutschein-Codes',
    'code_length_tt'                   => 'Gib hier die Länge des Gutschein-Codes ein. (max. 16 Zeichen)',
    'welcome_voucher_coupon'           => 'Willkommensgeschenk/-rabatt',
    'welcome_voucher_value'            => 'Willkommensgeschenk Gutscheinwert',
    'welcome_voucher_value_tt'         => 'Willkommensgeschenk Gutscheinwert: Wenn du keinen Gutschein in deiner Willkommens-E-Mail versenden willst, verwende den Wert 0.00, ansonsten gib den Wert des Gutscheins an. Z. B. 10.00 oder 50.00, aber keine Währungszeichen',
    'welcome_coupon_code'              => 'Willkommensrabatt-Couponcode',
    'welcome_coupon_code_tt'           => 'Willkommensrabatt-Couponcode: Wenn du keinen Coupon in deiner Willkommens-E-Mail versenden willst, lasse dieses Feld leer, ansonsten tragen den Couponcode ein, den du verwenden willst.',
];
